;******************************************************************************************************
; Le 10/03/2019 "Animations Enseigne-Feux-Croix.asm.asm" sur PIC 16F690  8 Mhz
; Le 05/03/2020  Version V3  temporisation plus longue pour les pauses des tubes fluo et arc.
;
; Montage : Animations_Ense-Feux-croix : 
;
; Version pour : Enseigne 6 lampes + Feux tricolores + Croix pharmacie + Soudure  l'arc + Tube fluorescent + Feu de camp.
;
; Site web : http://www.la-tour.info/uts/uts_index.html
; Montage, schma, notice, typon, explication, circuit imprim, programme assembleur microchip pour pic  cette adresse internet.
;
; Montage  PIC 16F690 pour alimenter des charges relies au + 12 volts.
; Sert sur un rseau de train. Rubrique : Modlisme ferroviaire et lectronique locomotive maquette animation et clairage
;
; Deux groupes de 8 sorties branchs sur 2 ULN2803.
; Un potentiomtre permet de rgler la vitesse d'animation.
;
; L'entre R3 est relie aux sorties via des diodes et des cavaliers pour dterminer le choix  la mise sous tension :
;
;------ RA5 RA4 RC5 RC4 : Mode (I => Cavalier en place) ------------
;        4   3   2   1
; RA3 :              0  : Enseigne
; RA3 :              I  : Croix
; RA3 :          0 + I  : Croix + Tube fluo n1
; RA3 :          I + I  : Croix + Soudure  l'arc n1
; RA3 :          0      : Feux de camp sur 2 lampes + Tube fluo n3
; RA3 :          I      : Feux de camp sur 3 lampes
; RA3 :      0          : Chenillard
; RA3 :      I          : Feux tricolores
; RA3 :  0              : Soudure  l'arc n2
; RA3 :  I              : Tube fluo n2
;
;*******************************************************************
;
; L'utilisation des pattes du PIC 16F690
;
; RA0 - Entre analogique CAN0 (0-5 Volts) = Vitesse d'animation.
; RA3 - Entre RA3 multiplexe avec les sorties RA5 RA4 RC5 RC4 via une diode + rsistance de rappel  la masse.
;
; Sorties Groupe 1
;   RA5 - Enseigne 1/6 - Croix 1/5
;   RA4 - Enseigne 2/6 - Croix 2/5
;   RC5 - Enseigne 3/6 - Croix 3/5
;   RC4 - Enseigne 4/6 - Croix 4/5
;   RC3 - Enseigne 5/6 - Croix 5/5
;   RC6 - Enseigne 6/6 - Tube fluo n1 - Soudure  l'arc n1
;   RC7 - Flamme n1
;   RB7 - Flamme n2
;
; Sorties Groupe 2
;   RA1 - Chenillard 1/6 - Feux Tricolore Rouge  1
;   RA2 - Chenillard 2/6 - Feux Tricolore Orange 1
;   RC0 - Chenillard 3/6 - Feux Tricolore Vert   1
;   RC1 - Chenillard 4/6 - Feux Tricolore Rouge  2
;   RC2 - Chenillard 5/6 - Feux Tricolore Orange 2
;   RB4 - Chenillard 6/6 - Feux Tricolore Vert   2
;   RB5 - Soudure  l'arc n2 - Tube fluo n2
;   RB6 - Flamme n3 - Tube fluo n3
;
; Tube Fluo 1 = Nombreuses tentatives d'allumages puis reste allum un certain temps.
; Tube Fluo 2 = Nombreuses tentatives d'allumages mais reste allum qu'un petit moment.
; Tube Fluo 3 = Tentatives d'allumages en continu, ne parvient pas  s'allumer.
;
; Soudure  l'arc 1 = Fonctionne 32 secs suivi d'une pause de 24 secs. 0,3  0,8 secs de pause courte, 5  21 flashs de suite
; Soudure  l'arc 2 = Fonctionne 24 secs suivi d'une pause de 32 secs. 0,5    2 secs de pause courte, 10  41 flashs de suite
;
; Utilise la routine : Calcul de valeur alatoire : http://www.piclist.com/techref/microchip/rand8bit.htm
; Utilise la routine : Calcul de valeur alatoire : https://www.dontronics.com/psbpix/random.html
;
; Mmoire du PIC 16F690 = 4Ko = 0x0000  0x0FFF.
; Page 0 = 0x000  0x7FF, page 0x800  0xFFF.
; Sous programme d'initialisation en 0x900 en page 1, pour laisser de la place en page 0.
;
;
;*******************************************************************
;
	LIST p=16F690, R=DEC ; Utilisation du mode dcimal.
	include	"P16F690.inc"
;
;	Code non protg,  oscill interne sans sortie, pas de dtection tension basse, pas d'utilisation de la patte MCLR, dmarrage lent, Watchdog hors service
	__config (_INTRC_OSC_NOCLKOUT & _WDT_OFF & _PWRTE_OFF & _MCLRE_OFF & _CP_OFF & _BOR_OFF & _IESO_OFF & _FCMEN_OFF)
;
; _INTRC_OSC_NOCLKOUT  EQU  H'3FFC'    ; INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN
;                                      ; FOSC<2:0> = 100
; _WDT_OFF             EQU  H'3FF7'    ; WDT disabled and can be enabled by SWDTEN bit of the WDTCON register
; _PWRTE_OFF           EQU  H'3FFF'    ; PWRT disabled
; _MCLRE_OFF           EQU  H'3FDF'    ; MCLR pin function is digital input, MCLR internally tied to VDD
; _CPD_OFF             EQU  H'3FFF'    ; Data memory code protection is disabled
; _CP_OFF              EQU  H'3FFF'    ; Program memory code protection is disabled
; _BOREN_OFF           EQU  H'3CFF'    ; BOR disabled
; _IESO_OFF            EQU  H'3BFF'    ; Internal External Switchover mode is disabled
; _FCMEN_OFF           EQU  H'37FF'    ; Fail-Safe Clock Monitor is disabled
;

BANK0	macro			; MACRO : Passer en banque0.
	bcf	STATUS,RP0
	bcf	STATUS,RP1
	endm
BANK1	macro			; Passer en banque1.
	bsf	STATUS,RP0
	bcf	STATUS,RP1
	endm
BANK2	macro			; Passer en banque2.
	bcf	STATUS,RP0
	bsf	STATUS,RP1
	endm

;
;*************************************************************************************************************
;
; Dfinitions des constantes internes modifiables par l'utilisateur.
VIT_FEU	EQU	153	; Vitesse de base pour les feux tricolores (1 = rapide, 153 = moyen, 255 = lent).
VIT_CHE	EQU	9	; Vitesse de base pour le chenillard       (1 = rapide,   9 = moyen, 255 = lent).

VIT_ENS	EQU	31	; Vitesse de base pour l'enseigne (1 = rapide, 31 = moyen, 255 = lent).
VIT_CRO	EQU	17	; Vitesse de base pour la croix   (1 = rapide, 17 = moyen, 255 = lent).

; Tube Fluo 1 = Cinq tentatives d'allumage puis reste allum un temps relativement long.
VIT_FL1	EQU	 7	; Vitesse de base pour le tube fluo 1 (1 = rapide, 7 = moyen, 255 = lent).
POS_FL1	EQU	14	; Dure de pause longue dure du tube fluo 1, par pas de 5 secondes (1=5sec rapide, 14=70sec moyen, 255=20mn lent).

; Tube Fluo 2 = Nombreuses tentatives d'allumage, mais ne reste allum qu'un court moment.
VIT_FL2	EQU 	 8	; Vitesse de base pour le tube fluo 2 (1 = rapide, 8 = moyen, 255 = lent).
POS_FL2	EQU	12	; Dure de pause longue dure du tube fluo 2, par pas de 5 secondes (1=5sec rapide, 12=60sec moyen, 255=20mn lent).

; Tube Fluo 3 = Tentatives d'allumage en continu, mais ne parvient pas  s'allumer.
VIT_FL3	EQU	 9	; Vitesse de base pour le tube fluo 3 (1 = rapide, 9 = moyen, 255 = lent).
POS_FL3	EQU	10	; Dure de pause longue dure du tube fluo 3, par pas de 5 secondes (1=5sec rapide, 10=50sec moyen, 255=20mn lent).

; Soudure  l'arc 1 =	Fonctionne 40 secs suivi d'une pause de 90 secs. De 0,3  0,8 secs de pauses courtes, de 5  21 flashs de suite.
ACT_AR1 EQU	 4	; Dure de fonctionnement de l'arc 1,     par pas de 10 secondes (1=10sec rapide, 4=40sec moyen, 255=40mn lent).
POS_AR1	EQU	 9	; Dure de pause longue dure de l'arc 1, par pas de 10 secondes (1=10sec rapide, 9=90sec moyen, 255=40mn lent).

; Soudure  l'arc 2 =	Fonctionne 30 secs suivi d'une pause de 70 secs. De 0,5  2 secs de pauses courtes, de 10  41 flashs de suite.
ACT_AR2 EQU	 3	; Dure de fonctionnement de l'arc 2,     par pas de 10 secondes (1=10sec rapide, 3=30sec moyen, 255=40mn lent).
POS_AR2	EQU	 7	; Dure de pause longue dure de l'arc 2, par pas de 10 secondes (1=10sec rapide, 7=70sec moyen, 255=40mn lent).

;
;*************************************************************************************************************
;
	CBLOCK 0x20     ; La table des variables commence  0x20.

	cpt_can		; Compteur pour la demande de conversion CAN.
	can_lue1	; Valeur du convertisseur A/N brute = 0-255.
	can_lue2	; Valeur du convertisseur A/N traite = 128+/-64 = 64  192.

	cpt_feut1	; Compteurs de temporisation pour feux tricolores.
	cpt_feut2	; //
	cpt_feut3	; Compteur de squence lumineuse pour feux tricolores.

	cpt_chen1	; Compteurs de temporisation pour chenillard  6 lampes.
	cpt_chen2	; //
	cpt_chen3	; Compteur de squence lumineuse pour chenillard  6 lampes.

	cpt_ense1	; Compteurs de temporisation pour enseigne  6 lampes.
	cpt_ense2	; //
	cpt_ense3	; Compteur de squence lumineuse pour enseigne  6 lampes.

	cpt_croi1	; Compteurs de temporisation pour croix  5 lampes.
	cpt_croi2	; //
	cpt_croi3	; Compteur de squence lumineuse pour croix  5 lampes.

	cpt_flam00	; N d'effet en cours.
	cpt_flam01	; Compteur de boucle principale pour l'effet en cours.
	cpt_flam02	; 1er  compteur de dlai en cours.
	cpt_flam03	; 2eme compteur de dlai en cours.
	cpt_flam11	; Puissance flamme n 1.
	cpt_flam12	; Puissance flamme n 1.
	cpt_flam21	; Puissance flamme n 2.
	cpt_flam22	; Puissance flamme n 2.
	cpt_flam31	; Puissance flamme n 3.
	cpt_flam32	; Puissance flamme n 3.

	cpt_fluo11	; 1er  Compteur de temps d'activit/inactivit.
	cpt_fluo12	; 2me Compteur de temps d'activit/inactivit.
	cpt_fluo13	; 3me Compteur de temps d'activit/inactivit.

	cpt_fluo14	; Compteur de squence lumineuse pour tube fluorescent. 
	cpt_fluo15	; Etat gnral de fonctionnement du tube.
			;   bit(0)=0 => Tube en fonctionnement longue dure
			;   bit(0)=1 => Tube en pause longue dure

	cpt_fluo21	; 1er  Compteur de temps d'activit/inactivit.
	cpt_fluo22	; 2me Compteur de temps d'activit/inactivit.
	cpt_fluo23	; 3me Compteur de temps d'activit/inactivit.

	cpt_fluo24	; Compteur de squence lumineuse pour tube fluorescent. 
	cpt_fluo25	; Etat gnral de fonctionnement du tube.
			;   bit(0)=0 => Tube en fonctionnement longue dure.
			;   bit(0)=1 => Tube en pause longue dure.

	cpt_fluo31	; 1er  Compteur de temps d'activit/inactivit.
	cpt_fluo32	; 2me Compteur de temps d'activit/inactivit.
	cpt_fluo33	; 3me Compteur de temps d'activit/inactivit.

	cpt_fluo34	; Compteur de squence lumineuse pour tube fluorescent. 
	cpt_fluo35	; Etat gnral de fonctionnement du tube.
			;   bit(0)=0 => Tube en fonctionnement longue dure.
			;   bit(0)=1 => Tube en pause longue dure.

	cpt_arc11	; Compteurs de temporisation pour soudure  l'arc 1.
	cpt_arc12	; //
	cpt_arc13	; //
	cpt_arc14	; //
	cpt_arc15	; //
	cpt_arc16	; //
	cpt_arc17	; //
	cpt_arc18	; Etat gnral de fonctionnement de l'arc.

	cpt_arc21	; Compteurs de temporisation pour soudure  l'arc 2.
	cpt_arc22	; //
	cpt_arc23	; //
	cpt_arc24	; //
	cpt_arc25	; //
	cpt_arc26	; //
	cpt_arc27	; //
	cpt_arc28	; Etat gnral de fonctionnement de l'arc.

	cpt_inter	; Compteur d'interruption pour les sorties PMW.

	temp1		; Variable locale
	temp2		; Variable locale
	mode		; Mode de fonctionnement du programme = Lecture des cavaliers 1  4.

	varale1s : 3	; Variable alatoire sur 16 bits + une variable de combinaison en +3.
	varale2s : 3	; Variable alatoire sur 16 bits + une variable de combinaison en +3.

	w_temp		; Sauvegardes pour les interruptions.
	status_temp	; //
	PCLATH_temp	; //

	ENDC
;
;*******************************************************************
; Dbut du programme.
;
	org		0x2100 	  			 ; Initialize EEPROM Data
	dt 		"ENSEIGNE_FEUX_CROIX_V3_Pauses_longues_"	; Texte visible dans le '.hex'.
	dt		"Le 05/03/2020 "
	dt		"http://www.la-tour.info/uts/uts_index.html"
    ORG     0x000
	goto    init
	org     0x004
	goto    interrupt
	dt 		"__ENSEIGNE_FEUX_CROIX_V3_Pauses_longues__"		; Textes visibles dans le '.hex'.
	dt		"__Le 05/03/2020___"
	dt		"http://www.la-tour.info/uts/uts_index.html"	;
;
;
;***************************************************************************************
;
; Traitement des interruptions du timer TMR0 pour gnrer les sortie PWM des flammes
; A 8 Mhz Interruption TMR0 = 112 S =  224 instructions dans la bocule principale.
; Comme il y du code dans ce sous programme d'interruption, on passe dans cette routine
; toutes les 117 s + 15 s = 132 s. Ce qui donne pour une rsolution de la PMW sur 128 niveaux = 59 hz.
;
; On charge les valeurs de PMW ici de faon synchrone pour viter des sursauts de lumire.
; On alimente la led flamme n 3 que si le cavalier n3 est en place.
; 
interrupt
	bcf     INTCON,GIE	; Inhibe toutes les interruptions.
	movwf   w_temp  	; Sauve le registre W.
	swapf	STATUS,w	; Swap status avec rsultat dans w.
	movwf	status_temp	; Sauver le STATUS. Pas besoin de passer en BANK0, car on n'utilise ni BANK1 ni BANK2 dans la boucle principale.
	incf	cpt_inter,f	; Compteur pour les flammes 1 + 2 + 3.
	incf	cpt_inter,f
	btfss	STATUS,Z
	goto	chrgpwm
	movf	cpt_flam11,w	; On charge les valeurs quand le compteur = 0,
	movwf	cpt_flam12	; soit toutes les 17 msec = 58 Hz, de faon synchrone
	movf	cpt_flam21,w	; pour viter un sursaut de lumire.
	movwf	cpt_flam22
	movf	cpt_flam31,w
	movwf	cpt_flam32
chrgpwm	movf	cpt_inter,w	; Flamme 1.
	subwf	cpt_flam12,w	; cpt_flam11 = Valeur de la puissance de la flamme 1 PWM : 0-255, avec une rsolution de 128 niveaux.
	btfsc	STATUS,C
	bsf	PORTC,7		; Allume la flamme 1 PWM.
	btfss	STATUS,C
	bcf	PORTC,7		; Eteint la flamme 1 PWM.
	movf	cpt_inter,w	; Flamme 2.
	subwf	cpt_flam22,w	; cpt_flam21 = Valeur de la puissance de la flamme 2 PWM : 0-255, avec une rsolution de 128 niveaux.
	btfsc	STATUS,C
	bsf	PORTB,7		; Allume la flamme 2 PWM.
	btfss	STATUS,C
	bcf	PORTB,7		; Eteint la flamme 2 PWM.
	btfss	mode,1		; Cavalier[1]=1 ? => Flamme 3
	goto	pasfla3		; Cavalier = 0 !
	movf	cpt_inter,w	; Flamme 3.
	subwf	cpt_flam32,w	; cpt_flam31 = Valeur de la puissance de la flamme 3 PWM : 0-255, avec une rsolution de 128 niveaux.
	btfsc	STATUS,C
	bsf	PORTB,6		; Allume la flamme 3 PWM.
	btfss	STATUS,C
	bcf	PORTB,6		; Eteint la flamme 3 PWM.
pasfla3	movlw   199		; Dure = (255-XXX)*temps_us du Timer0 (=112S/2S) = 56.   255-56 = 199.
	movwf   TMR0		; Interruption toutes les 112s*2 = 224 instructions  partir d'ici.
	bcf     INTCON,T0IF	; Remise  0 du drapeau de dpassement du Timer0 pour la prochaine interruption.
	swapf	status_temp,w	; swap ancien status, rsultat dans w
	movwf   STATUS		; restaurer status
	swapf   w_temp,f	; Inversion L et H de l'ancien W sans modifier Z
	swapf   w_temp,w  	; Rinversion de L et H dans W. W restaur sans modifier status
	retfie  			; return from interrupt
;
;
;********************************************************************************************
;
;	Squence d'inititialisation du PIC ici.
; 	Suite de cette squence en 0x900, pour ne pas encombrer la plage 0x000  x0x4FF.
;
init	bsf	PCLATH,3	; Prpare le saut en page n0 vers n1 (0x800 - 0xFFF).
	call	init_suite	; Saut en page n 1.
	bcf	PCLATH,3	; On reste en page n0 (0x000 - 0x7FF) pour les CALL !
	movlw   199		; Dure = (255-XXX)*temps_us du Timer0 (=112S/2S) = 56.   255-56 = 199.
	movwf   TMR0		; Interruption toutes les 112s*2 = 224 instructions  partir d'ici.
	bcf     INTCON,T0IF	; Remise  0 du drapeau de dpassement du Timer0 pour la prochaine interruption.
	bsf     INTCON,GIE	; initialisation finie, on autorise toutes les interruptions.

;
; Boucle principale
; --------------------------------------------------------------------------------------------
; On restera en BANK0, on ne passe plus en BANK1 ou BANK2 dans cette boucle principale.
; --------------------------------------------------------------------------------------------
;
boucle	
	decfsz	cpt_can,f	; On ne lit le potentiomtre qu'une fois sur 256 = 38 msec.
	goto	t_debut

	btfsc	ADCON0,GO       ; Nouveau calcul de cptlen = Lecture valeur du potentiomtre entre 0 et 255.	
	goto	$-1		; Normalement la dernire conversion est finie depuis longtemps.
	movf	ADRESH,w
	sublw	255		; Inverse la valeur, car le potentiomtre est cbl  l'envers sur le circuit imprim.
	movwf	can_lue1  	; Vitesse = can_lue1 => 0-255.
	movwf	can_lue2
	sublw	255
	btfss	STATUS,Z
	incf	can_lue1,f   	; Vitesse = can_lue1 => 1-255, pour faire fonctionner les boucles 'decfsz' correctement.
	bcf	STATUS,C
	rrf	can_lue2,f
	movlw	64
	addwf	can_lue2,f	; Vitesse = can_lue2 = 1-255 128 +/- 64 = 64  191 pour une plage rduite de rglage
	bsf	ADCON0,GO       ; Relance la prochaine conversion can.
can_02	movlw	45		; 45 = 50-5 => Boucle de 100 s de temporisation au total avec conversion CAN.
	goto	t_debut+1	; pour quilibrer le temps perdu.

t_debut	movlw	50		; 50 => Boucle de 100 s de temporisation.
	movwf	temp1		; Permet d'tablir un nombre moyen d'instruction par tour de programme.
	decfsz	temp1,f		; Boucle de X tours pour temporiser un peu le programme ici, histoire 
	goto	$-1		; d'quilibrer les retards suivants le passages dans les diffrentes boucles.


;********************************************************************************************************;
; Calcul des valeurs alatoires sur 16 bits pour les squences lumineuses.
; Initialiser les registres 'varale1s' et 'varale2s' avec une valeur diffrente de zro sur 16 bits.
; Source web : https://www.dontronics.com/psbpix/random.html
;            : http://www.joescat.com/micro/pic/an544_rng.html
; 16bit Pseudo Squence Random Number Generator (RNG).
; Based on Microchip's MATH routine found in AN544 and modified to fit all picchips including the tiny 12bit versions.
; This version uses 10 program words, making it slightly faster, but it needs a temp scratch pad to work.
; This RNG is based on linear shift register feedback. Sequence is generated by (Q15 xor Q14 xor Q12 xor Q3).
;
; Ne pas modifier les variables 'varale1s' et 'varale1s+1', autre part dans le programme.
; Utiliser les variables 'varale1s' et 'varale1s+1' sans les modifier.
;
	movf	varale1s,w	; First, ensure that hiB and lowB aren't
	iorwf	varale1s+1,w	; all zeros. If they are, NOT hiB to FFh.
	btfsc	STATUS,Z	; Otherwise, leave hiB and lowB as is.
	comf	varale1s,f
	movlw	0x80		; We want to XOR hiB.7, hiB.6, hiB.4
	btfsc	varale1s,6	; and lowB.3 together in W. Rather than
	xorwf	varale1s,f	; try to line up these bits, we just
	btfsc	varale1s,4	; check to see whether a bit is a 1. If it
	xorwf	varale1s,f	; is, XOR 80h into hiB. If it isn't,
	btfsc	varale1s+1,3	; do nothing. When we're done, the
	xorwf	varale1s,f	; XOR of the 4 bits will be in hiB.7.
	rlf	varale1s,w	; Move hiB.7 into carry.
	rlf	varale1s+1,f	; Rotate c into lowB.0, lowB.7 into c.
	rlf	varale1s,f	; Rotate c into hiB.0.
	movf	varale1s+1,w
	xorwf	varale1s,w	; 'w' = 'varale1s' + 'varale1s+1'
	movwf	varale1s+2

	movf	varale2s,w	; First, ensure that hiB and lowB aren't
	iorwf	varale2s+1,w	; all zeros. If they are, NOT hiB to FFh.
	btfsc	STATUS,Z	; Otherwise, leave hiB and lowB as is.
	comf	varale2s,f
	movlw	0x80		; We want to XOR hiB.7, hiB.6, hiB.4
	btfsc	varale2s,6	; and lowB.3 together in W. Rather than
	xorwf	varale2s,f	; try to line up these bits, we just
	btfsc	varale2s,4	; check to see whether a bit is a 1. If it
	xorwf	varale2s,f	; is, XOR 80h into hiB. If it isn't,
	btfsc	varale2s+1,3	; do nothing. When we're done, the
	xorwf	varale2s,f	; XOR of the 4 bits will be in hiB.7.
	rlf	varale2s,w	; Move hiB.7 into carry.
	rlf	varale2s+1,f	; Rotate c into lowB.0, lowB.7 into c.
	rlf	varale2s,f	; Rotate c into hiB.0.
	movf	varale2s+1,w
	xorwf	varale2s,w	; 'w' = 'varale2s' + 'varale2s+1'
	movwf	varale2s+2


feu_debut
	btfss	mode,2		; Cavalier[3]=1 ? => Feux Tricolore
	goto	chen_debut	; Cavalier = 0 !
;
; -------------------------------------------------------
; Squence Feux tricolores
;
; RA1 - Feux Tricolore Rouge  1
; RA2 - Feux Tricolore Orange 1
; RC0 - Feux Tricolore Vert   1
; RC1 - Feux Tricolore Rouge  2
; RC2 - Feux Tricolore Orange 2
; RB4 - Feux Tricolore Vert   2
; -------------------------------------------------------
;
	decfsz	cpt_feut1,f
	goto	ense_debut
	movlw	VIT_FEU		; 153 = vitesse moyenne pour can = 128.
	movwf	cpt_feut1	; Initialisation du compteur de temporisation pour une tempo moyenne.
       	decfsz	cpt_feut2,f	; quand "cpt_feut2" = 128.
	goto	ense_debut
	movf	can_lue2,w	; 128+/-64 = 64  192.
	movwf	cpt_feut2	; Initialisation du compteur de temporisation.
 	movlw	0x05
	movwf	PCLATH
	movf	cpt_feut3,w	; cpt_feut3 = Compteur de squence des feux tricolores.	
	call	table_feut	; Valeurs des lampes => temp1.
	movwf	temp1

	btfss	temp1,5		; Rouge 1
	bcf	PORTA,1
	btfsc	temp1,5
	bsf	PORTA,1
	btfss	temp1,4		; Orange 1
	bcf	PORTA,2
	btfsc	temp1,4
	bsf	PORTA,2
	btfss	temp1,3		; Vert 1
	bcf	PORTC,0
	btfsc	temp1,3
	bsf	PORTC,0

	btfss	temp1,2		; Rouge 2
	bcf	PORTC,1
	btfsc	temp1,2
	bsf	PORTC,1
	btfss	temp1,1		; Orange 2
	bcf	PORTC,2
	btfsc	temp1,1
	bsf	PORTC,2
	btfss	temp1,0		; Vert 2
	bcf	PORTB,4
	btfsc	temp1,0
	bsf	PORTB,4

	incf	cpt_feut3,f	; cpt_feut3 = Compteur de squence des feux tricolores.
	btfsc	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1.
	clrf	cpt_feut3
	goto	ense_debut


chen_debut		
	btfsc	mode,2		; Cavalier[3]=0 ? => Chenillard zone de travaux.
	goto	chen_debut	; Cavalier = 1 !;
; -------------------------------------------------------
; Squence chenillard  6 lampes.
;
; RA1 - Chenillard travaux lampe n 1 (Dbut animation)
; RA2 - n 2
; RC0 - n 3
; RC1 - n 4
; RC2 - n 5
; RB4 - n 6 (Fin animation)
; -------------------------------------------------------
;
	decfsz	cpt_chen1,f
	goto	ense_debut
	movlw	VIT_CHE		; 9 vitesse moyenne.
	movwf	cpt_chen1	; Initialisation du compteur de temporisation pour une tempo moyenne
	decfsz	cpt_chen2,f	; quand "cpt_chen2" = 128.
	goto	ense_debut
	movf	can_lue2,w	; 128+/-64 = 64  191.
	movwf	cpt_chen2	; Initialisation du compteur de temporisation.
 	movlw	0x05
	movwf	PCLATH
	movf	cpt_chen3,w	; cpt_chen3 = Compteur de squence du chenillard de travaux.	
	call	table_chen	; Valeurs des lampes => temp1.
	movwf	temp1
	btfss	temp1,5		; Lampe 1 (dbut animation)
	bcf	PORTA,1
	btfsc	temp1,5
	bsf	PORTA,1
	btfss	temp1,4		; Lampe 2
	bcf	PORTA,2
	btfsc	temp1,4
	bsf	PORTA,2
	btfss	temp1,3		; Lampe 3
	bcf	PORTC,0
	btfsc	temp1,3
	bsf	PORTC,0
	btfss	temp1,2		; Lampe 4
	bcf	PORTC,1
	btfsc	temp1,2
	bsf	PORTC,1
	btfss	temp1,1		; Lampe 5
	bcf	PORTC,2
	btfsc	temp1,1
	bsf	PORTC,2
	btfss	temp1,0		; Lampe 6 (fin animation)
	bcf	PORTB,4
	btfsc	temp1,0
	bsf	PORTB,4
	incf	cpt_chen3,f	; cpt_chen3 = Compteur de squence du chenillard.
	btfsc	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1.
	clrf	cpt_chen3


ense_debut
	btfsc	mode,0		; Cavalier[0]=0 ? => Enseigne.
	goto	croi_debut	; Cavalier = 1 !
;
; -------------------------------------------------------
; Squence Enseigne sur 6 lampes.
;
; RA5 - Enseigne 1/6 (Lampe du haut)
; RA4 - Enseigne 2/6
; RC5 - Enseigne 3/6
; RC4 - Enseigne 4/6
; RC3 - Enseigne 5/6
; RC6 - Enseigne 6/6 (Lampe du bas)
; -------------------------------------------------------
;
	decfsz	cpt_ense1,f
	goto	flam1_debut
	movlw	VIT_ENS		; 31 = vitesse moyenne.
	movwf	cpt_ense1	; Initialisation du compteur de temporisation pour une tempo moyenne
	decfsz	cpt_ense2,f	; quand "cpt_ense2" = 128.
	goto	flam1_debut
	movf	can_lue2,w	; 128+/-64 = 64  192.
	movwf	cpt_ense2	; Initialisation du compteur de temporisation.
 	movlw	0x05
	movwf	PCLATH
	movf	cpt_ense3,w	; cpt_ense3 = Compteur de squence de l'enseigne.
	call	table_ense	; Valeurs des lampes => temp1.
	movwf	temp1
	btfss	temp1,5		; Enseigne lampe n 1 du haut
	bcf	PORTA,5
	btfsc	temp1,5
	bsf	PORTA,5
	btfss	temp1,4		; Enseigne lampe n 2.
	bcf	PORTA,4
	btfsc	temp1,4
	bsf	PORTA,4
	btfss	temp1,3		; Enseigne lampe n 3.
	bcf	PORTC,5
	btfsc	temp1,3
	bsf	PORTC,5
	btfss	temp1,2		; Enseigne lampe n 4.
	bcf	PORTC,4
	btfsc	temp1,2
	bsf	PORTC,4
	btfss	temp1,1		; Enseigne lampe n 5.
	bcf	PORTC,3
	btfsc	temp1,1
	bsf	PORTC,3
	btfss	temp1,0		; Enseigne lampe n 6 du bas.
	bcf	PORTC,6
	btfsc	temp1,0
	bsf	PORTC,6
	incf	cpt_ense3,f	; cpt_ense3 = Compteur de squence de l'enseigne.
	btfsc	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1.
	clrf	cpt_ense3
	goto	flam1_debut


croi_debut			; Cavalier[0]=1 ? => Croix de pharmacie.
;
; -------------------------------------------------------
; Squence Croix sur 5 lampes.
;
; RA5 - Croix 1/5
; RA4 - Croix 2/5       2
; RC5 - Croix 3/5     1 5 3
; RC4 - Croix 4/5       4
; RC3 - Croix 5/5
; -------------------------------------------------------
;
	decfsz	cpt_croi1,f
	goto	flam1_debut
	movlw	VIT_CRO		; 17 = vitesse moyenne.
	movwf	cpt_croi1	; Initialisation du compteur de temporisation pour une tempo moyenne
	decfsz	cpt_croi2,f	; quand "cpt_croi2" = 128.
	goto	flam1_debut
	movf	can_lue2,w	; 128+/-64 = 64  191.
	movwf	cpt_croi2	; Initialisation du compteur de temporisation.
 	movlw	0x06
	movwf	PCLATH
	movf	cpt_croi3,w	; cpt_croi3 = Compteur de squence de l'enseigne.
	call	table_croix	; Valeurs des lampes => temp1.
	movwf	temp1
	btfss	temp1,0		; Croix gauche n 1.
	bcf	PORTA,5
	btfsc	temp1,0
	bsf	PORTA,5
	btfss	temp1,1		; Croix haut n 2.
	bcf	PORTA,4
	btfsc	temp1,1
	bsf	PORTA,4
	btfss	temp1,2		; Croix droit n 3.
	bcf	PORTC,5
	btfsc	temp1,2
	bsf	PORTC,5
	btfss	temp1,3		; Croix bas n 4.
	bcf	PORTC,4
	btfsc	temp1,3
	bsf	PORTC,4
	btfss	temp1,4		; Croix centre n 5.
	bcf	PORTC,3
	btfsc	temp1,4
	bsf	PORTC,3
	incf	cpt_croi3,f	; cpt_chen3 = Compteur de squence de la croix de pharmacie.
	btfsc	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1.
	clrf	cpt_croi3


flam1_debut
; ----------------------------------------------------------------------------
; Squence Flammes  2 ou 3 lampes.
; On calcule pour 3 led, dans le sspg d'interruption, on valide ou non la led n 3.
;
; RC7 - Flamme 1 (PWM alatoire)
; RB7 - Flamme 2 (PWM alatoire)
; RB6 - Flamme 3 (PWM alatoire) 
;
; cpt_flam00 = Numro d'effet en cours = 0-10. + suite des effet en n 11 et 13.
; cpt_flam01 = Compteur de boucle principale pour passer N fois dans un effet. 
; cpt_flam02 = 1er  compteur de dlai en cours = 17 => Dcompte les 2,5 msec.
; cpt_flam03 = 2eme compteur de dlai en cours = N * 2,5 msec.
;
; cpt_flam11 = Valeur de puissance calcule PMW 0-255.
; cpt_flam21 = Valeur de puissance recopie dans la routine d'interruption.
; ----------------------------------------------------------------------------
;
	decfsz	cpt_flam02,f
	goto	fluo1_debut
	movlw	17
	movwf	cpt_flam02	; 17 => cpt_flam02, pour avoir cpt_flam03 qui compte les 2,5 millisecondes (17*150s). 
	decfsz	cpt_flam03,f	; Dlai. On passe ici toutes les 2,5 milli-seconde.
	goto	fluo1_debut
	decfsz	cpt_flam01,f	; cpt_flam01 = Compteur de boucles pour un effet.
	goto	fe00
	movf	cpt_flam00,w
	sublw	7
	btfss	STATUS,Z
	goto	f001
	movlw	11		; Si l'effet tait = 7 => On enchaine avec l'effet = 11.
	movwf	cpt_flam00
	goto	f003
f001	movf	cpt_flam00,w
	sublw	9
	btfss	STATUS,Z
	goto	f002
	movlw	13		; Si l'effet tait = 9 => On enchaine avec l'effet = 13.
	movwf	cpt_flam00
	goto	f003
f002	movf	varale1s,w	; Changement alatoire d'effet entre 0 et 10.
	andlw	0x07
	movwf	cpt_flam00	; 0-7
	btfsc	varale1s,5
	incf	cpt_flam00,f	; 0-8
	btfsc	varale1s,6
	incf	cpt_flam00,f	; 0-9
	btfsc	varale1s,7
	incf	cpt_flam00,f	; 0-10
f003	movf	cpt_flam00,w	; 0-10 = cpt_flam00 => N du prochain effet.
	call	table_flam
	movwf	cpt_flam01	; cpt_flam01 = 1-255 => Nb de boucles  raliser pour le prochain effet.
	incf	cpt_flam01,f
	movlw	1
	movwf	cpt_flam03	; 1 => Pour passer dans l'effet directement.
	goto	fluo1_debut
fe00	btfsc	cpt_flam00,0
	goto	fe10
;------------------------------ EFFET 00,02,04,06,08,10 : FLAMMES NORMALES. 80  120 boucles = 7  10 secondes d'animation.
	bcf	STATUS,C	; Puissance = [Ancienne_Puissance + Alatoire(0-127)] / 2
	rrf	varale1s,w	; Pour ne pas toucher  cpt_flam11 lors du calcul intermdiaire.
	movwf	temp1
	bcf	STATUS,C	
	rrf	cpt_flam11,w
	addwf	temp1,w
	movwf	cpt_flam11	; 0-255 => Flamme 1.
	bcf	STATUS,C	; Puissance = [Ancienne_Puissance + Alatoire(0-127)] / 2
	rrf	varale1s+1,w
	movwf	temp1
	bcf	STATUS,C	
	rrf	cpt_flam21,w
	addwf	temp1,w
	movwf	cpt_flam21	; 0-255 => Flamme 2.
	bcf	STATUS,C	; Puissance = [Ancienne_Puissance + Alatoire(0-127)] / 2
	rrf	varale2s,w
	movwf	temp1
	bcf	STATUS,C	
	rrf	cpt_flam31,w
	addwf	temp1,w
	movwf	cpt_flam31	; 0-255 => Flamme 3.
	movf	varale2s+1,w	; Temporisation en 2 * milli-secondes
	andlw	0x3F		; 0-63.
	addlw	10
	movwf	cpt_flam03	; 10-73 => 20  146 msec , Temporisation en fois 2,5 * msec.
	goto	fluo1_debut
fe10	movf	cpt_flam00,w
	sublw	1
	btfss	STATUS,Z
	goto	fe30
;------------------------------ EFFET 01 - cpt_flam00=1 : ROTATION DES 3 FLAMMES. 48 boucles = 10 secondes d'animation.
	movf	cpt_flam11,w
	movwf	temp2
	bcf	STATUS,C	; Puissance = [Ancienne_Puissance + Alatoire(0-127)] / 2
	rrf	varale1s,w	; Pour ne pas toucher  cpt_flam11 lors du calcul intermdiaire.
	movwf	temp1
	bcf	STATUS,C	
	rrf	cpt_flam31,w
	addwf	temp1,w
	movwf	cpt_flam11	; 0-255 => Flamme 1.
	bcf	STATUS,C	; Puissance = [Ancienne_Puissance + Alatoire(0-127)] / 2
	rrf	varale1s+1,w
	movwf	temp1
	bcf	STATUS,C	
	rrf	cpt_flam11,w
	addwf	temp1,w
	movwf	cpt_flam21	; 0-255 => Flamme 2.
	bcf	STATUS,C	; Puissance = [Ancienne_Puissance + Alatoire(0-127)] / 2
	rrf	varale2s,w
	movwf	temp1
	bcf	STATUS,C	
	rrf	temp2,w
	addwf	temp1,w
	movwf	cpt_flam31	; 0-255 => Flamme 3.
	movf	varale2s+1,w	; Temporisation en milli-secondes.
	andlw	0x7F		; 0-127.
	addlw	30
	movwf	cpt_flam03	; 30-157 => 60  314 msec, Temporisation en fois 2,5 * msec.
	goto	fluo1_debut
fe30	movf	cpt_flam00,w
	sublw	3
	btfss	STATUS,Z
	goto	fe50
;------------------------------ EFFET 03 - cpt_flam00=3 : FLAMMES RAPIDES. 60 boucles = 5 secondes d'animation.
	movf	varale1s,w	;
	movwf	cpt_flam11	; 0-255 => Flamme 1.
	movf	varale1s+1,w	;
	movwf	cpt_flam21	; 0-255 => Flamme 2.
	movf	varale2s,w	;
	movwf	cpt_flam31	; 0-255 => Flamme 3.
	movf	varale2s+1,w	; Temporisation en milli-secondes.
	andlw	0x3F		; 0-63.
	addlw	10
	movwf	cpt_flam03	; 10-73 => 20  146 msec, Temporisation en 2,5 * ms.
	goto	fluo1_debut
fe50	movf	cpt_flam00,w
	sublw	5
	btfss	STATUS,Z
	goto	fe70
;------------------------------ EFFET 05 - cpt_flam00=5 : FLAMMES PUISSANTES. 41 boucles = 5 secondes d'animation.
	movf	varale1s,w
	andlw	0x7F		; 0-127
	addlw	100
	movwf	cpt_flam11	; 100-227 => Flamme 1.
	movf	varale1s+1,w
	andlw	0x7F		; 0-127
	addlw	100
	movwf	cpt_flam21	; 100-227 => Flamme 2.
	movf	varale2s,w
	andlw	0x7F		; 0-127
	addlw	100
	movwf	cpt_flam31	; 100-227 => Flamme 3.
	movf	varale2s+1,w	; Temporisation en milli-secondes.
	andlw	0x3F		; 0-36.
	addlw	30
	movwf	cpt_flam03	; 30-93 => 60  183 msec, Temporisation en 2,5 * ms.
	goto	fluo1_debut
fe70	movf	cpt_flam00,w
	sublw	7
	btfss	STATUS,Z
	goto	fe90
;------------------------------ EFFET 07 - cpt_flam00=7 : EXTINCTION PUIS RALLUMAGE LENT(effet n11).  224 boucles =  8 secondes d'animation.
	movf	cpt_flam01,w	; cpt_flam01 = Compteur de boucles pour cet effet 224->0.
fe71	movwf	temp1		; ici w est renseign, on le met dans temp1. Il faut mettre 225 dans la table !
	movf	varale1s,w
	andlw	0x1F		; 0-31
	addwf	temp1,w	; 224+(0-31)  0+(0-31)
	movwf	cpt_flam11	; => Flamme 1.
	movf	varale1s+1,w
	andlw	0x1F		; 0-31
	addwf	temp1,w	; 224 +(0-31)  0+(0-31)
	movwf	cpt_flam21	; => Flamme 2.
	movf	varale2s,w
	andlw	0x1F		; 0-31
	addwf	temp1,w	; 224 +(0-31)  0+(0-31)
	movwf	cpt_flam31	; => Flamme 3.
	movf	cpt_flam00,w
	sublw	7
	btfsc	STATUS,Z
	goto	fe72
	movf	cpt_flam00,w
	sublw	11
	btfsc	STATUS,Z
	goto	fe72	
	movf	varale2s+1,w	; Si effet n 9 ou n 13 on va plus vite.
	andlw	0x07		; 0-7
	addlw	5
	movwf	cpt_flam03	; 5-12 => 10  24 msec, Temporisation en 2,5 * ms.
	goto	fluo1_debut
fe72	movf	varale2s+1,w	; Si effet n 7 ou n 11 on va plus lentement.
	andlw	0x0F		; 0-15
	addlw	10
	movwf	cpt_flam03	; 10-25 => 20  50 msec, Temporisation en 2,5 * ms.
	goto	fluo1_debut
fe90	movf	cpt_flam00,w
	sublw	9
	btfss	STATUS,Z
	goto	feB0
;------------------------------ EFFET 09 - cpt_flam00=9 : EXTINCTION PUIS RALLUMAGE RAPIDE(effet n13).  128 boucles =  3 secondes d'animation.
	movf	cpt_flam01,w	; cpt_flam01 = Compteur de boucles pour cet effet 128->0.
	goto	fe71		; On reprend la squence n 7 avec tempo plus faible en sortie.
feB0	movf	cpt_flam00,w
	sublw	11
	btfss	STATUS,Z
	goto	feD0
;------------------------------ EFFET 11 - cpt_flam00=11 : RALLUMAGE LENT suite effet n 7.
	movf	cpt_flam01,w	; cpt_flam01 = Compteur de boucles pour cet effet 224->0.
	movwf	temp1		; cpt_flam01 de 224  0
	comf	temp1,w		; Donne => temp1 et w de 0  224	
	addlw	-31		; Ici w est renseign.
	goto	fe71		; On reprend la squence n 7  l'envers.
feD0	movf	cpt_flam00,w
	sublw	13
	btfss	STATUS,Z
	goto	fluo1_debut
;------------------------------ EFFET 13 - cpt_flam00=11 : RALLUMAGE RAPIDE suite effet n 9.
	movf	cpt_flam01,w	; cpt_flam01 = Compteur de boucles pour cet effet 128->0.
	movwf	temp1		; cpt_flam01 de 128  0
	comf	temp1,w		; Donne => temp1 et w de 0  128	
	addlw	-128		; Ici w est renseign.
	goto	fe71		; On reprend la squence n 7  l'envers avec tempo plus faible en sortie.




fluo1_debut
	btfss	mode,0		; Cavalier[1]=1 ? => Fluo 1
	goto	fluo2_debut	; Cavalier = 1 !
	btfsc	mode,1		; Cavalier[2]=0 ? => Fluo 1
	goto	fluo2_debut	; Cavalier = 0 !
; -------------------------------------------------------
; Squence tubes fluorescents.
; cpt_fluo11	; 1er  Compteur de temps actif/inactif.
; cpt_fluo12	; 2me Compteur de temps actif/inactif.
; cpt_fluo13	; 3me Compteur de temps actif/inactif.
; cpt_fluo14	; Compteur de squence lumineuse pour tube fluorescent. 
; cpt_fluo15	; Etat gnral de fonctionnement du tube.
; 		; bit(0)=0 => Tube en fonctionnement longue dure
; 		; bit(0)=1 => Tube en pause longue dure
; Des temps d'attente lgrement diffrents dans cpt_fluox2,
; pour viter des allumages synchrones.
;
; Tube Fluo 1 = Cinq tentatives d'allumage puis reste allum un temps relativement long.
; Tube Fluo 2 = Nombreuses tentatives d'allumage, mais ne reste allum qu'un court moment.
; Tube Fluo 3 = Tentatives d'allumage en continu, mais ne parvient pas  s'allumer.
;
; -------------------------------------------------------
; Squence tube fluorescent 1.
;
; RC6 - Tube fluorescent 1
; -------------------------------------------------------
	btfss	cpt_fluo15,0	; Tube fluorescent 1 en pose longue dure ?
	goto	f1en_ma

	decfsz	cpt_fluo11,f 	; TUBE EN PAUSE LONGUE DUREE !
	goto	fluo2_debut
	movlw	127
	movwf	cpt_fluo11
	decfsz	cpt_fluo12,f	; On passe ici toutes les 19 ms (128*150 s).
	goto	fluo2_debut
	decfsz	cpt_fluo13,f	; On passe ici toutes les 5 secondes.
	goto	fluo2_debut	; Le temps de pause = 5*cpt_fluo13 (Secondes).
	bcf	cpt_fluo15,0	; Retour  la squence => Tube en fonctionnement longue dure.
	movlw	1
	movwf	cpt_fluo11	; cpt_fluoxx=1 => Pour passer directement dans la boucle.
	movwf	cpt_fluo12
	clrf	cpt_fluo14	; Raz du compteur de squence lumineuse.
	goto	fluo2_debut
f1en_ma	decfsz	cpt_fluo11,f	; TUBE EN FONCTIONNEMENT LONGUE DUREE !
	goto	fluo2_debut
	movlw	127
	movwf	cpt_fluo11
	decfsz	cpt_fluo12,f	; On passe ici toutes les 19 ms (128*150 s).
	goto	fluo2_debut
	movlw	VIT_FL1		; 9 = Vitesse moyenne = 0,17 sec.
	movwf	cpt_fluo12	; On passe ici toutes les 0,17 secondes = Pas de lecture de la table 'table_fluo'.
	movlw	0x07
	movwf	PCLATH
	movf	cpt_fluo14,w	; cpt_fluo14 = Compteur de squence de tube fluorescent.
	call	table_fluo	; Valeurs des lampes => temp1.
	movwf	temp1
	btfss	temp1,0		; Tube fluorescent 1.
	bcf	PORTC,6
	btfsc	temp1,0
	bsf	PORTC,6
	incf	cpt_fluo14,f	; cpt_fluo14 = Compteur de squence du tube fluo.
	btfss	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1 ?
	goto	fluo2_debut
	bsf	cpt_fluo15,0	; Retour  la squence => Tube en pause longue dure.
	movlw	POS_FL1		; => Temps en seconde*5 (12=1 mn) de la pause longue dure.
	movwf	cpt_fluo13

fluo2_debut
	btfss	mode,3		; Cavalier[3]=1 ? => Fluo 2
	goto	fluo3_debut	; Cavalier = 0
; -------------------------------------------------------
; Squence tube fluorescent 2.
;
; RB5 - Tube fluorescent 2
; -------------------------------------------------------
	btfss	cpt_fluo25,0	; Tube fluorescent 2 en pose longue dure ?
	goto	f2en_ma
	decfsz	cpt_fluo21,f 	; TUBE EN PAUSE LONGUE DUREE !
	goto	fluo3_debut
	movlw	129		; Dures lgrement diffrentes pour viter des boucles synchrones.
	movwf	cpt_fluo21
	decfsz	cpt_fluo22,f	; On passe ici toutes les 17 ms (128*150 s).
	goto	fluo3_debut
	decfsz	cpt_fluo23,f	; On passe ici toutes les 5 secondes.
	goto	fluo3_debut	; Le temps de pause = 5*cpt_fluo23 (Secondes).
	bcf	cpt_fluo25,0	; Retour  la squence => Tube en fonctionnement longue dure.
	movlw	1
	movwf	cpt_fluo21	; cpt_fluoxx=1 => Pour passer directement dans la boucle.
	movwf	cpt_fluo22
	clrf	cpt_fluo24	; Raz du compteur de squence lumineuse.
	goto	fluo3_debut
f2en_ma	decfsz	cpt_fluo21,f	; TUBE EN FONCTIONNEMENT LONGUE DUREE !
	goto	fluo3_debut
	movlw	129
	movwf	cpt_fluo21
	decfsz	cpt_fluo22,f	; On passe ici toutes les 17ms (128*150 s).
	goto	fluo3_debut
	movlw	VIT_FL2		; 8 = Vitesse moyenne = 0,17 sec.
	movwf	cpt_fluo22	; On passe ici toutes les 0,17 secondes = Pas de lecture de la table 'table_fluo'.
	movlw	0x07
	movwf	PCLATH
	movf	cpt_fluo24,w	; cpt_fluo24 = Compteur de squence de tube fluorescent.
	call	table_fluo	; Valeurs des lampes => temp1.
	movwf	temp1
	btfss	temp1,1		; Tube fluorescent 2.
	bcf	PORTB,5
	btfsc	temp1,1
	bsf	PORTB,5
	incf	cpt_fluo24,f	; cpt_fluo24 = Compteur de squence du tube fluo.
	btfss	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1 ?
	goto	fluo3_debut
	bsf	cpt_fluo25,0	; Retour  la squence => Tube en pause longue dure.
	movlw	POS_FL2		; => Temps en seconde*12 (12=1 mn) de la pause longue dure.
	movwf	cpt_fluo23

fluo3_debut
	btfsc	mode,1		; Cavalier[1]=0 ? => Fluo 3
	goto	arc1_debut	; Cavalier = 1 !
; -------------------------------------------------------
; Squence tube fluorescent 3.
;
; RB6 - Tube fluorescent 3
; -------------------------------------------------------
	btfss	cpt_fluo35,0	; Tube fluorescent 3 en pose longue dure ?
	goto	f3en_ma
	decfsz	cpt_fluo31,f 	; TUBE EN PAUSE LONGUE DUREE !
	goto	arc1_debut
	movlw	130
	movwf	cpt_fluo31
	decfsz	cpt_fluo32,f	; On passe ici toutes les 17 ms (128*150 s).
	goto	arc1_debut
	decfsz	cpt_fluo33,f	; On passe ici toutes les 5 secondes.
	goto	arc1_debut	; Le temps de pause = 5*cpt_fluo33 (Secondes).
	bcf	cpt_fluo35,0	; Retour  la squence => Tube en fonctionnement longue dure.
	movlw	1
	movwf	cpt_fluo31	; cpt_fluoxx=1 => Pour passer directement dans la boucle.
	movwf	cpt_fluo32
	clrf	cpt_fluo34	; Raz du compteur de squence lumineuse.
	goto	arc1_debut
f3en_ma	decfsz	cpt_fluo31,f	; TUBE EN FONCTIONNEMENT LONGUE DUREE !
	goto	arc1_debut
	movlw	130
	movwf	cpt_fluo31
	decfsz	cpt_fluo32,f	; On passe ici toutes les 17 ms (128*150 s).
	goto	arc1_debut
	movlw	VIT_FL3		; 7 = Vitesse moyenne = 0,17 sec.
	movwf	cpt_fluo32	; On passe ici toutes les 0,17 secondes = Pas de lecture de la table 'table_fluo'.
	movlw	0x07
	movwf	PCLATH
	movf	cpt_fluo34,w	; cpt_fluo34 = Compteur de squence de tube fluorescent.
	call	table_fluo	; Valeurs des lampes => temp1.
	movwf	temp1
	btfss	temp1,2		; Tube fluorescent 3.
	bcf	PORTB,6
	btfsc	temp1,2
	bsf	PORTB,6
	incf	cpt_fluo34,f	; cpt_fluo34 = Compteur de squence du tube fluo.
	btfss	temp1,7		; Dernire valeur valide. Fin de table => Bit(7) = 1 ?
	goto	arc1_debut
	bsf	cpt_fluo35,0	; Retour  la squence => Tube en pause longue dure.
	movlw	POS_FL3		; => Temps en seconde*5 (12=1 mn) de la pause longue dure.
	movwf	cpt_fluo33


arc1_debut
	btfss	mode,0		; Cavalier[1]=1 ? => Arc 1
	goto	arc2_debut	; Cavalier = 0 !
	btfss	mode,1		; Cavalier[3]=1 ? => Arc 1
	goto	arc2_debut	; Cavalier = 0 !
; -------------------------------------------------------
; Squence arcs lectriques.
;
; cpt_arc11	; 1er  Compteur de temps de temps actif/temps inactif. En marche 40sec / 3mn.
; cpt_arc12	; 2me Compteur de temps de temps actif/temps inactif.
; cpt_arc13	; 3me Compteur de temps de temps actif/temps inactif.
;
; cpt_arc14	; 4me Compteur de temps de temps arrt/nb de squence lumineuse de suite = 10  21.
; cpt_arc15	; 5me Compteur de temps de temps arrt. Arrt entre 2 squences = 0,5  2 secondes.
;
; cpt_arc16	; 6me Compteur de temps Flash teint/lumineux. /Dure d'un flash = 10  101 ms
; cpt_arc17	; 7me Compteur de temps Flash teint/lumineux. \Dure entre deux flashs = 10  31 ms
; cpt_arc18	; Etat gnral de fonctionnement de l'arc.
;
; 		; bit(0)=0 => Flash en pause longue trs dure.
; 		; bit(0)=1 => Flash en fonctionnement trs longue dure.
;
; 		; bit(1)=0 => Flash en arrt courte dure.
; 		; bit(1)=1 => Flash en marche courte dure.
;
; 		; bit(2)=0 => Flash teint.
; 		; bit(2)=1 => Flash lumineux.
;
; Soudure  l'arc 1 = Fonctionne 32 secs suivi d'une pause de 24 secs. De 0,3  0,8 secs de pauses courtes, de  5  21 flashs de suite.
; Soudure  l'arc 2 = Fonctionne 24 secs suivi d'une pause de 32 secs. De 0,5  2   secs de pauses courtes, de 10  41 flashs de suite
;
; -------------------------------------------------------
; Squence arc lectrique 1.
;
; RC6 - Arc lectrique 1.
; -------------------------------------------------------

	btfsc	cpt_arc18,0	; Arc 1 actif/inactif longue dure ?
	goto	a1en_ma

	decfsz	cpt_arc11,f 	; Ici, on est en mode INACTIF TRES LONGUE DUREE.
	goto	arc2_debut
	decfsz	cpt_arc12,f	; On passe ici toutes les 38 ms (256*150 s).
	goto	arc2_debut
	decfsz	cpt_arc13,f	; On passe ici toutes les 10 secondes.
	goto	arc2_debut
	movlw	1
	movwf	cpt_arc14
	movwf	cpt_arc15
	movlw	ACT_AR2		; 3 = temps actif = 30 secondes actif = 3*10  secs.
	movwf	cpt_arc13	; cpt_arcx3 =  Temps du prochain fonctionnement longue dure.
	clrf	cpt_arc18	; Bit(1)=0 =>  Flash en arrt courte dure + Bit(2)=0 => Flash teint.
	bsf	cpt_arc18,0	; Bit(0)=1 =>  Retour  la squence => Arc en fonctionnement longue dure.
	goto	arc2_debut	; On change de mode => Mode actif longue dure (cpt_arc_11, 12, 13, 16, 17).

a1en_ma	decfsz	cpt_arc11,f 	; Ici, on est en mode ACTIF TRES LONGUE DUREE.
	goto	a1en_mb
	decfsz	cpt_arc12,f	; On passe ici toutes les 38 ms (256*150 s).
	goto	a1en_mb
	decfsz	cpt_arc13,f	; On passe ici toutes les 10 secondes.
	goto	a1en_mb
	movlw	POS_AR2		; Exemple 4 = Temps de pause = 40 secondes inactif = 4*10 secs.
	movwf	cpt_arc13	; cpt_arcx3 =  Temps de la prochaine pause longue dure.
	bcf	PORTC,6		; On teint le flash.
	bcf	cpt_arc18,0	; Bit(0)=0 =>  Retour  la squence => Arc en pause longue dure.
	goto	arc2_debut	; On change de mode => Mode inactif longue dure (cpt_arc_11, 12, 13).

a1en_mb	btfss	cpt_arc18,1
	goto	a1en_me
	btfsc	cpt_arc18,2
	goto	a1en_md	

	decfsz	cpt_arc16,f	; Ici, on est en mode ACTIF TRES LONGUE DUREE + MARCHE COURTE DUREE + FLASH ETEINT.
	goto	arc2_debut
	movlw	9
	movwf	cpt_arc16	; 9 pour 1 millisecondes par boucle.	
	decfsz	cpt_arc17,f
	goto	arc2_debut
	decfsz	cpt_arc14,f	; Fin de courte squence de flash allum.
	goto	a1en_mc
	movf	varale1s,w	; 0-255  On  fini les squences de flash.	
	andlw	0x1F
	movwf	cpt_arc15	; 0-31
	movf	varale1s+1,w	; 0-255
	andlw	0x0F		; 0-15
	addlw	16		; 16-31
	addwf	cpt_arc15,f	; 16-62 pour 0,5  2 secondes de pause courte (cpt14+cpt15). (255 = 10 sec).
	bcf	cpt_arc18,1	; Bit(1) = 0. 
	goto	arc2_debut	; On change de mode => Flash en arrt courte dure (cpt_arc_14, 15).

a1en_mc	movf	varale1s,w	; 0-255
	andlw	0x3F		
	movwf	cpt_arc17	; 0-63
	movf	varale1s+1,w	; 0-255
	andlw	0x1F		; 0-31
	addlw	10		; 10-41
	addwf	cpt_arc17,f	; 10-104  cpt_arc17 = 10  104 ms.
	bsf	PORTC,6		; On allume le flash.
	bsf	cpt_arc18,2	; Bit(2) = 1. Flash allume.
	goto	arc2_debut	; On change de mode => Flash allum (cpt_arc_16 + cpt_arc17).

a1en_md	decfsz	cpt_arc16,f	; Ici, on est en mode ACTIF TRES LONGUE DUREE + MARCHE COURTE DUREE + FLASH ALLUME.
	goto	arc2_debut	
	movlw	9
	movwf	cpt_arc16	; 9 pour 1 millisecondes par boucle.	
	decfsz	cpt_arc17,f
	goto	arc2_debut	
	movwf	cpt_arc17	; cpt_arc17 = 10  101 ms.
	movf	varale1s,w	; 0-255
	andlw	0x0F		
	movwf	cpt_arc17	; 0-15
	movf	varale1s+1,w	; 0-255
	andlw	0X07		; 0-7
	addlw	10		; 10-17
	addwf	cpt_arc17,f	; 10-34  cpt_arc17 = 10  34 ms.
	bcf	PORTC,6		; on teint le flash.
	bcf	cpt_arc18,2	; Bit(2) = 0. Flash teint.
	goto	arc2_debut	; On change de mode => Flash teint (cpt_arc_16,17).
	
a1en_me	decfsz	cpt_arc14,f	; Ici, on est en mode ACTIF TRES LONGUE DUREE + ARRET COURTE DUREE.
	goto	arc2_debut
	decfsz	cpt_arc15,f	; On passe ici toutes les 30 msec.
	goto	arc2_debut
				; On passe ici apres une courte pause de 1,5  8 secondes.
	movf	varale1s,w	; 0-255
	andlw	0x1F		; 0-31
	addlw	10		; 10-41
	movwf	cpt_arc14	; 10  41 squences lumineuses de suite.
	movlw	9
	movwf	cpt_arc16	; 9 pour 1 millisecondes par boucle.	
	movlw	50
	movwf	cpt_arc17	; cpt_arc17 = 10  101 ms. 1er flash fixe de 50 sec.
	bsf	PORTC,6		; On allume le flash.
	bsf	cpt_arc18,1	; Bit(1)=1 =>  Flash en marche courte dure.
	bsf	cpt_arc18,2	; Bit(2)=1 =>  Flash allum.
	goto	arc2_debut	; On change de mode => Marche + Flash allum (cpt_arc_14, 16, 17).
	

arc2_debut
	btfsc	mode,3		; Cavalier[4]=0 ? => Arc 2
	goto	anim_fin	; Cavalier = 1 !
; -------------------------------------------------------
; Squence arc lectrique 2.
;
; RB5 - Arc lectrique 2
; -------------------------------------------------------
	btfsc	cpt_arc28,0	; Arc 2 actif/inactif longue dure ?
	goto	a2en_ma

	decfsz	cpt_arc21,f 	; Ici, on est en mode INACTIF TRES LONGUE DUREE.
	goto	anim_fin
	decfsz	cpt_arc22,f	; On passe ici toutes les 38 ms (256*150 s).
	goto	anim_fin
	decfsz	cpt_arc23,f	; On passe ici toutes les 10 secondes.
	goto	anim_fin
	movlw	1
	movwf	cpt_arc24
	movwf	cpt_arc25
	movlw	ACT_AR1		; 4 = temps actif = 40 secondes actif = 5*8  secs.
	movwf	cpt_arc23	; cpt_arcx3 =  Temps du prochain fonctionnement longue dure.
	clrf	cpt_arc28	; Bit(1)=0 =>  Flash en arrt courte dure + Bit(2)=0 => Flash teint.
	bsf	cpt_arc28,0	; Bit(0)=1 =>  Retour  la squence => Arc en fonctionnement longue dure.
	goto	anim_fin	; On change de mode => Mode actif longue dure (cpt_arc_11, 12, 13, 16, 17).

a2en_ma	decfsz	cpt_arc21,f 	; Ici, on est en mode ACTIF TRES LONGUE DUREE.
	goto	a2en_mb
	decfsz	cpt_arc22,f	; On passe ici toutes les 38 ms (256*150 s).
	goto	a2en_mb
	decfsz	cpt_arc23,f	; On passe ici toutes les 10 secondes.
	goto	a2en_mb
	movlw	POS_AR2		; Exemple 3 = Temps de pause = 30 secondes inactif = 3*10 secs.
	movwf	cpt_arc23	; cpt_arcx3 =  Temps de la prochaine pause longue dure.
	bcf	PORTB,5		; On teint le flash.
	bcf	cpt_arc28,0	; Bit(0)=0 =>  Retour  la squence => Arc en pause longue dure.
	goto	anim_fin	; On change de mode => Mode inactif longue dure (cpt_arc_11, 12, 13).

a2en_mb	btfss	cpt_arc28,1
	goto	a2en_me
	btfsc	cpt_arc28,2
	goto	a2en_md	

	decfsz	cpt_arc26,f	; Ici, on est en mode ACTIF TRES LONGUE DUREE + MARCHE COURTE DUREE + FLASH ETEINT.
	goto	anim_fin
	movlw	9
	movwf	cpt_arc26	; 9 pour 1,3 millisecondes par boucle.	
	decfsz	cpt_arc27,f
	goto	anim_fin
	decfsz	cpt_arc24,f	; Fin de courte squence de flash allum.
	goto	a2en_mc
	movf	varale1s,w	; 0-255  On  fini les squences de flash.	
	andlw	0x1F
	movwf	cpt_arc25	; 0-31
	movf	varale1s+1,w	; 0-255
	andlw	0x0F		; 0-15
	addlw	8		; 8-23
	addwf	cpt_arc25,f	; 10-23 pour 0,3  0,8 secondes de pause(cpt14+cpt15). (255 = 8 sec).
	bcf	cpt_arc28,1	; Bit(1) = 0. 
	goto	anim_fin	; On change de mode => Flash en arrt courte dure (cpt_arc_14, 15).

a2en_mc	movf	varale1s,w	; 0-255
	andlw	0x3F		
	movwf	cpt_arc27	; 0-63
	movf	varale1s+1,w	; 0-255
	andlw	0x1F		; 0-31
	addlw	10		; 10-41
	addwf	cpt_arc27,f	; 10-104  cpt_arc27 = 10  104 ms.
	bsf	PORTB,5		; On allume le flash.
	bsf	cpt_arc28,2	; Bit(2) = 1. Flash allume.
	goto	anim_fin	; On change de mode => Flash allum (cpt_arc_16 + cpt_arc27).

a2en_md	decfsz	cpt_arc26,f	; Ici, on est en mode ACTIF TRES LONGUE DUREE + MARCHE COURTE DUREE + FLASH ALLUME.
	goto	anim_fin	
	movlw	9
	movwf	cpt_arc26	; 9 pour 1 millisecondes par boucle.	
	decfsz	cpt_arc27,f
	goto	anim_fin	
	movwf	cpt_arc27	; cpt_arc27 = 10  101 ms.
	movf	varale1s,w	; 0-255
	andlw	0x0F		
	movwf	cpt_arc27	; 0-15
	movf	varale1s+1,w	; 0-255
	andlw	0X07		; 0-7
	addlw	10		; 10-17
	addwf	cpt_arc27,f	; 10-34  cpt_arc27 = 10  34 ms.
	bcf	PORTB,5		; on teint le flash.
	bcf	cpt_arc28,2	; Bit(2) = 0. Flash teint.
	goto	anim_fin	; On change de mode => Flash teint (cpt_arc_16,17).
	
a2en_me	decfsz	cpt_arc24,f	; Ici, on est en mode ACTIF TRES LONGUE DUREE + ARRET COURTE DUREE.
	goto	anim_fin
	decfsz	cpt_arc25,f	; On passe ici toutes les 30 msec.
	goto	anim_fin
				; On passe ici apres une courte pause de 1,5  8 secondes.
	movf	varale1s,w	; 0-255
	andlw	0x0F		; 0-16
	addlw	5		; 5-21
	movwf	cpt_arc24	; 5  21 squences lumineuses de suite.
	movlw	9
	movwf	cpt_arc26	; 9 pour 1 millisecondes par boucle.	
	movlw	50
	movwf	cpt_arc27	; cpt_arc27 = 10  101 ms. 1er flash fixe de 50 sec.
	bsf	PORTB,5		; On allume le flash.
	bsf	cpt_arc28,1	; Bit(1)=1 =>  Flash en marche courte dure.
	bsf	cpt_arc28,2	; Bit(2)=1 =>  Flash allum.
	goto	anim_fin	; On change de mode => Marche + Flash allum (cpt_arc_14, 16, 17).

anim_fin
	goto	boucle

;
;*******************************************************************
;*******************************************************************
;*******************************************************************
; Entre w = Compteur de squence pour feux tricolores.
; Retour w = Valeurs des 6 lampes = --ROVROV (Bit = 1 = lampe allume)
;          = Bit(7)= 1 = fin de table => Faire raz compteur.
;
; w      = 0 0 0 0 0 0 0  0  0 0 1 1 1 1 1  1
;          0 1 2 3 4 5 6  7  8 9 0 1 2 3 4  5
; Feux 1 = R R R R R R R  R  V V V V V V O  R
; Feux 2 = V V V V V V O  R  R R R R R R R  R
;
; Utilisation de la table :
; 	movlw	0x05
;	movwf	PCLATH
;	movf	cpt_feut3,w	
;	call	table_feut
;
	ORG 0x500		; Adresse des tableaux en fin de mmoire (moins de 256 octets par table)
table_feut:
	addwf	PCL,f		; Ajouter w  PCL
	retlw	b'00100001'	;  0 Retour : Lampes = X, X, Rouge 1, Orange 1, Vert 1, Rouge 2, Orange 2, Vert 2
	retlw	b'00100001'	;  1
	retlw	b'00100001'	;  2
	retlw	b'00100001'	;  3
	retlw	b'00100001'	;  4
	retlw	b'00100001'	;  5
	retlw	b'00100010'	;  6
	retlw	b'00100100'	;  7
	retlw	b'00001100'	;  8
	retlw	b'00001100'	;  9
	retlw	b'00001100'	; 10
	retlw	b'00001100'	; 11
	retlw	b'00001100'	; 12
	retlw	b'00001100'	; 13
	retlw	b'00010100'	; 14
	retlw	b'10100100'	; 15  Dernire valeur valide. Fin de table => Bit(7) = 1.

;**********************************************************************
; Entre w = Compteur de squence pour le chenillard de travaux  6 lampes.
; Retour w = Valeurs des 6 lampes = XX123456 (Bit = 1 = lampe allume)
;          = Bit(7)= 1 = fin de table => Faire raz compteur.
;
; Utilisation de la table :
; 	movlw	0x05
;	movwf	PCLATH
;	movf	cpt_chen3,w
;	call	table_chen
;
;	ORG 0x500+?		; Adresse des tableaux en fin de mmoire (moins de 256 octets par table)
table_chen:
	addwf	PCL,f		; Ajouter w  PCL
	retlw	b'00100000'	;  0 retour lampe = XX123456 = Lampes : 1(dbut), 2, 3, 4, 5, 6(fin)
	retlw	b'00010000'	;
	retlw	b'00001000'	;
	retlw	b'00000100'	;
	retlw	b'00000010'	;
	retlw	b'00000001'	;
	retlw	b'00000001'	;
	retlw	b'00000000'	;
	retlw	b'10000000'	; Dernire valeur valide. Fin de table => Bit(7) = 1.


;*******************************************************************
; Entre w = 0  = Compteur de squence pour enseigne  6 lampes
; Retour w = Valeurs des 6 lampes = XX123456 (Bit = 1 = lampe allume)
;          = Bit(7)= 1 = fin de table => Faire raz compteur.
;
; Utilisation de la table :
; 	movlw	0x05
;	movwf	PCLATH
;	movf	cpt_ense3,w	
;	call	table_ense
;
;	ORG 0x500+?		; Adresse des tableaux en fin de mmoire (moins de 256 octets par table)
table_ense:
	addwf	PCL,f		; Ajouter w  PCL
	retlw	b'00100000'	;  Retour : Lampes = X, X, lampes 1(lampe du haut), 2, 3, 4, 5, 6 (lampe du bas)
	retlw	b'00010000'	;
	retlw	b'00001000'	;  1
	retlw	b'00000100'	;
	retlw	b'00000010'	;
	retlw	b'00000001'	;
	retlw	b'00100001'	;
	retlw	b'00010001'	;
	retlw	b'00001001'	;
	retlw	b'00000101'	;
	retlw	b'00000011'	;
	retlw	b'00100011'	;
	retlw	b'00010011'	;
	retlw	b'00001011'	;
	retlw	b'00000111'	;
	retlw	b'00100111'	;
	retlw	b'00010111'	;
	retlw	b'00001111'	;
	retlw	b'00101111'	;
	retlw	b'00011111'	;
	retlw	b'00111111'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00111111'	; 2
	retlw	b'00011111'	;
	retlw	b'00001111'	;
	retlw	b'00000111'	;
	retlw	b'00000011'	;
	retlw	b'00000001'	;
	retlw	b'00000000'	;

	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00100001'	; 3
	retlw	b'00110011'	;
	retlw	b'00111111'	;
	retlw	b'00100001'	;
	retlw	b'00110011'	;
	retlw	b'00111111'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;

	retlw	b'00000000'	; 4
	retlw	b'00110000'	; 
	retlw	b'00001100'	;
	retlw	b'00000011'	;
	retlw	b'00110000'	;
	retlw	b'00001100'	;
	retlw	b'00000011'	;
	retlw	b'00110000'	;
	retlw	b'00001100'	;
	retlw	b'00000011'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00001000'	; 5
	retlw	b'00000100'	;
	retlw	b'00001100'	;
	retlw	b'00011100'	;
	retlw	b'00001110'	;
	retlw	b'00011110'	;
	retlw	b'00111110'	;
	retlw	b'00011111'	;
	retlw	b'00111111'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00100000'	; 6
	retlw	b'00110000'	;
	retlw	b'00011000'	;
	retlw	b'00001100'	;
	retlw	b'00000110'	;
	retlw	b'00000011'	;
	retlw	b'00000001'	;
	retlw	b'00000000'	;
	retlw	b'00000001'	;
	retlw	b'00000011'	;
	retlw	b'00000110'	;
	retlw	b'00001100'	;
	retlw	b'00011000'	;
	retlw	b'00110000'	;
	retlw	b'00100000'	;
	retlw	b'00000000'	;
	retlw	b'00100000'	;
	retlw	b'00110000'	;
	retlw	b'00011000'	;
	retlw	b'00001100'	;
	retlw	b'00000110'	;
	retlw	b'00000011'	;
	retlw	b'00000001'	;
	retlw	b'00000000'	;
	retlw	b'00000001'	;
	retlw	b'00000011'	;
	retlw	b'00000110'	;
	retlw	b'00001100'	;
	retlw	b'00011000'	;
	retlw	b'00110000'	;
	retlw	b'00100000'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00111111'	; 7
	retlw	b'00011111'	;
	retlw	b'00101111'	;
	retlw	b'00110111'	;
	retlw	b'00111011'	;
	retlw	b'00111101'	;
	retlw	b'00111110'	;
	retlw	b'00111101'	;
	retlw	b'00111011'	;
	retlw	b'00110111'	;
	retlw	b'00101111'	;
	retlw	b'00011111'	;
	retlw	b'00101111'	;
	retlw	b'00110111'	;
	retlw	b'00111011'	;
	retlw	b'00111101'	;
	retlw	b'00111110'	;
	retlw	b'00111101'	;
	retlw	b'00111011'	;
	retlw	b'00110111'	;
	retlw	b'00101111'	;
	retlw	b'00011111'	;
	retlw	b'00111111'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00100000'	; 8
	retlw	b'00010000'	;
	retlw	b'00101000'	;
	retlw	b'00010100'	;
	retlw	b'00001010'	;
	retlw	b'00000101'	;
	retlw	b'00001010'	;
	retlw	b'00010100'	;
	retlw	b'00101000'	;
	retlw	b'00010100'	;
	retlw	b'00001010'	;
	retlw	b'00000101'	;
	retlw	b'00001010'	;
	retlw	b'00010100'	;
	retlw	b'00101000'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;

	retlw	b'00000000'	; 9
	retlw	b'00010000'	;
	retlw	b'00010010'	;
	retlw	b'00011010'	;
	retlw	b'00111010'	;
	retlw	b'00111110'	;
	retlw	b'00111111'	;
	retlw	b'00101111'	;
	retlw	b'00101101'	;
	retlw	b'00001101'	;
	retlw	b'00001001'	;
	retlw	b'00001000'	;
	retlw	b'00000000'	;
	retlw	b'00000010'	;
	retlw	b'00100010'	;
	retlw	b'00110010'	;
	retlw	b'00110110'	;
	retlw	b'00110111'	;
	retlw	b'00111111'	;
	retlw	b'00111110'	;
	retlw	b'00110110'	;
	retlw	b'00110010'	;
	retlw	b'00010010'	;
	retlw	b'00000010'	;

	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'00111111'	;
	retlw	b'00000000'	;
	retlw	b'10111111'	; Dernire valeur valide. Fin de table => Bit(7) = 1.


;********************************************************************************
; Entre w = Numro d'effet pour les flammes (0  13).
; Retour w = Nombre de boucles pour les flammes.
;
; Utilisation de la table :
; 	movlw	0x05
;	movwf	PCLATH
;	movf	cpt_flam01,w
;	call	table_flam
;
;	ORG 0x500+?		; Adresse des tableaux en fin de mmoire (Moins de 256 octets par table).
table_flam:
	addwf	PCL,f		; Ajouter w  PCL
	retlw	120		;  0 Normal
	retlw	48		;  1 Rotation
	retlw	120		;  2 Normal
	retlw	60		;  3 Rapide
	retlw	120		;  4 Normal
	retlw	41		;  5 Puissant
	retlw	120		;  6 Normal
	retlw	225		;  7 Disparait + Rapparait lentement (en n 11). 225 obligatoire.
	retlw	80		;  8 Normal
	retlw	129		;  9 Disparait + Rapparait rapidement (en n 13). 129 obligatoire.
	retlw	80		; 10 Normal
	retlw	225		; 11 Rapparait lentement (suite du n 7) 225 obligatoire.
	retlw	80		; 12 Normal
	retlw	129		; 13 Rapparait rapidement en (suite du n 9). 129 obligatoire.
	retlw	0		; 14 Fin de table
	retlw	0		; 15 Fin de table


;*******************************************************************
; Entre w = 0  = compteur de squence pour la croix  5 lampes
; Retour w = Valeurs des 5 lampes = ---54321 (Bit = 1 => lampe allume)
;          = Bit(7)= 1 = fin de table => Faire raz compteur.
;
; Utilisation de la table :
; 	movlw	0x06
;	movwf	PCLATH
;	movf	cpt_croi3,w	
;	call	table_croi
;
	ORG 0x600		; Adresse des tableaux en fin de mmoire (Moins de 256 octets par table).
table_croix:
	addwf	PCL,f		; Ajouter w  PCL
	retlw	b'00000000'	; Retour : Lampes : X, X, lampes n 5, 4, 3, 2, 1 (5 = centre, 1=gauche)

	retlw	b'00010000'	; Clignote
	retlw	b'00001111'	;
	retlw	b'00010000'	;
	retlw	b'00001111'	;
	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00000000'	;

 	retlw	b'00000001'	;           2
	retlw	b'00011010'	; Croix = 1 5 3
	retlw	b'00000100'	;           4
	retlw	b'00000000'	;
 	retlw	b'00000001'	;
	retlw	b'00011010'	;
	retlw	b'00000100'	;
	retlw	b'00000000'	;
 	retlw	b'00000001'	;
	retlw	b'00011010'	;
	retlw	b'00000100'	;
	retlw	b'00000000'	;

	retlw	b'00001111'	; Clignote
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;

 	retlw	b'00000001'	;
 	retlw	b'00000011'	;           2
 	retlw	b'00000110'	; Croix = 1 5 3 
 	retlw	b'00001100'	;           4
 	retlw	b'00001001'	;
 	retlw	b'00000011'	;
 	retlw	b'00000110'	;
 	retlw	b'00001100'	;
 	retlw	b'00001001'	;
 	retlw	b'00000011'	;
 	retlw	b'00000110'	;
 	retlw	b'00001100'	;
 	retlw	b'00001001'	;
 	retlw	b'00000011'	;
 	retlw	b'00000110'	;
 	retlw	b'00001100'	;
 	retlw	b'00001001'	;

	retlw	b'00001111'	; Clignote
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;

 	retlw	b'00000000'	;
 	retlw	b'00000001'	;
 	retlw	b'00000010'	;
 	retlw	b'00000100'	;
 	retlw	b'00001000'	;
 	retlw	b'00001001'	;
 	retlw	b'00001010'	;
 	retlw	b'00001100'	;
 	retlw	b'00001101'	;
 	retlw	b'00001110'	;
 	retlw	b'00001111'	;
	retlw	b'00011111'	;
 	retlw	b'00000000'	;           2
 	retlw	b'00000001'	; Croix = 1 5 3 
 	retlw	b'00000010'	;           4
 	retlw	b'00000100'	;
 	retlw	b'00001000'	;
 	retlw	b'00001001'	;
 	retlw	b'00001010'	;
 	retlw	b'00001100'	;
 	retlw	b'00001101'	;
 	retlw	b'00001110'	;
 	retlw	b'00001111'	;
	retlw	b'00011111'	;
 	retlw	b'00000000'	;
 	retlw	b'00000001'	;
 	retlw	b'00000010'	;
 	retlw	b'00000100'	;
 	retlw	b'00001000'	;
 	retlw	b'00001001'	;
 	retlw	b'00001010'	;
 	retlw	b'00001100'	;
 	retlw	b'00001101'	;
 	retlw	b'00001110'	;
 	retlw	b'00001111'	;
	retlw	b'00011111'	;

	retlw	b'00001111'	; Clignote
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;

 	retlw	b'00000000'	;
 	retlw	b'00000101'	;           2
 	retlw	b'00001010'	; Croix = 1 5 3
 	retlw	b'00000101'	;           4
 	retlw	b'00001010'	;
 	retlw	b'00000101'	;
 	retlw	b'00001010'	;
 	retlw	b'00000101'	;
 	retlw	b'00001010'	;
 	retlw	b'00000101'	;
 	retlw	b'00001010'	;
 	retlw	b'00000101'	;
 	retlw	b'00001010'	;

	retlw	b'00001111'	; Clignote
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;

 	retlw	b'00000000'	;
 	retlw	b'00000001'	;
 	retlw	b'00010000'	;
 	retlw	b'00000100'	;
 	retlw	b'00000000'	;
 	retlw	b'00000010'	;
 	retlw	b'00010000'	;
 	retlw	b'00001000'	;
 	retlw	b'00000000'	;
 	retlw	b'00000001'	;
 	retlw	b'00010000'	;
 	retlw	b'00000100'	;
 	retlw	b'00000000'	;
 	retlw	b'00000010'	;
 	retlw	b'00010000'	;
 	retlw	b'00001000'	;
 	retlw	b'00000000'	;
 	retlw	b'00000001'	;
 	retlw	b'00010000'	;
 	retlw	b'00000100'	;
 	retlw	b'00000000'	;
 	retlw	b'00000010'	;
 	retlw	b'00010000'	;
 	retlw	b'00001000'	;
 	retlw	b'00000000'	;

	retlw	b'00001111'	; Clignote
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;
	retlw	b'00001111'	;
 	retlw	b'00010000'	;

 	retlw	b'00011110'	;
 	retlw	b'00011101'	;
 	retlw	b'00011011'	;           2
 	retlw	b'00010111'	; Croix = 1 5 3 
 	retlw	b'00011110'	;           4
 	retlw	b'00011101'	;
 	retlw	b'00011011'	;
 	retlw	b'00010111'	;
 	retlw	b'00011110'	;
 	retlw	b'00011101'	;
 	retlw	b'00011011'	;
 	retlw	b'10010111'	; Dernire valeur valide. Fin de table => Bit(7) = 1.

;*******************************************************************
; Entre w = Compteur de squence pour 3 tubes fluorescents
; Retour w = Valeurs des 3 lampes = XXXXX210 (Bit = 1 = lampe allume)
;          = Bit(7)= 1 = fin de table => Faire raz compteur.
;
; Tube Fluo 1 = Nombreuses tentatives d'allumages puis reste allum un certain temps.
; Tube Fluo 2 = Nombreuses tentatives d'allumages mais reste allum qu'un petit moment.
; Tube Fluo 3 = Tentatives d'allumages en continu, ne parvient pas  s'allumer.
;
; Utilisation de la table :
; 	movlw	0x07
;	movwf	PCLATH
;	movf	cpt_fluo,w	
;	call	table_fluo
;
	ORG 0x700		; Adresse des tableaux en fin de mmoire (moins de 256 octets par table)
table_fluo:
	addwf	PCL,f		; Ajouter w  PCL
	retlw	b'00000111'	; Retour : Lampes: X,X,X,X, lampe n 3, lampe n 2, lampe n  1.
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000110'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000110'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000011'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000110'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000100'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000101'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000110'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000010'
	retlw	b'00000100'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000011'
	retlw	b'00000000'
	retlw	b'00000010'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000110'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000111'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000110'
	retlw	b'00000000'
	retlw	b'00000110'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000110'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000010'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000100'
	retlw	b'00000010'
	retlw	b'00000000'
	retlw	b'00000101'
	retlw	b'00000110'
	retlw	b'00000110'
	retlw	b'00000100'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000000'
	retlw	b'00000000'
	retlw	b'00000011'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000101'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000111'
	retlw	b'00000101'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000111'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000101'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000101'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000001'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000011'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'
	retlw	b'00000111'	; Il faut que les dernires valeurs = '0' pour que les tubes soient teints pendant la pause longue.
	retlw	b'10000000'	; Dernire valeur valide. Fin de table => Bit(7) = 1.



;***************************************************************************************************************
; Dbut du code d'initialisation en page n1, 0x900 pour laisser de la place au programme
; principal en page n0 0x000-0x7FF.
; Attention, ici les 'call' ne doivent faire appel qu' des sous-programmes en page n1.
;
	ORG     0x900		; Le code dbute  l'origine de la page n1
init_suite
	BANK0
	movlw   b'00100000'     ; Interruptions = GIE=0 pour le moment, T0IE=1 (Timer overflow interrupt enable bit).
	movwf   INTCON
	movlw   b'00000001'     ; Format de conversion analogique 8 bits les plus forts sur un octet + Vref=+5V + Convertisseur=actif.
	movwf   ADCON0
;
	BANK1
	movlw   b'01110000'     ; 'x111'=Vitesse 8 Mhz + 'x'=OSTS interne + 'x'=HFINTOSC is stable + 'x'=LFINTOSC is stable + '0'=SCS interne.
	movwf	OSCCON		; 'x' = Bit en lecture seulement.
	movlw   b'00100000'     ; Dure de conversion analogique = 2 s = F/16 pour 8 Mhz.
	movwf   ADCON1
	BANK0
;
	clrf	PORTA           ; Au dpart, teint toutes les sorties.
	clrf	PORTB
	clrf	PORTC
;
;   T0CS   =   0 = Source interne pour TMR0
;   PSA    =   0 = Prdiviseur pour le Timer0
;   PS     = 001 = Prdiviseur pour Timer0 = 1/4 => (4*4)/8 Mhz = 2 sec
;
	BANK1
	movlw   b'11010001'     ; PortB, pas de rsistances de rappel, Timer0 Clock Source Select bit = Focs/4,
	movwf	OPTION_REG	; Prescaler is assigned to the Timer0 module.

	movlw   b'00110111'     ; '1'=Weak pull-up actif.
	movwf	WPUA

	clrf	PIE1	 	; '0'=Pas d'interruption.
	clrf	PIE2
	clrf	IOCA

	movlw   b'00001001'     ; PortA en sortie (4 bits) sauf RA0=Entre CAN0 et RA3=Entre numrique.
	movwf   TRISA

	clrf	TRISB		; PortB en sortie (4 bits).
	clrf	TRISC		; PortC en sortie (8 bits).
;
	BANK2
	movlw   b'00000001'     ; Utilisation de RA0 en entre analogique CAN0.
	movwf	ANSEL

	clrf	ANSELH		; Utilisation de RA0 en entre analogique CAN0.
	clrf	CM1CON0		; Les comparateurs ne sont pas utiliss.
	clrf	CM2CON0	
        BANK0


;*******************************************************************
; Initialisation des variables du programme.
;	
	movlw 0x20 		; Raz de toutes les variables.
	movwf FSR		; On charge l'adresse de dbut (0x20) de la zone des variables.
clr_var	clrf INDF		; Effacement du contenu du registre point par FSR
	incf FSR,f		; On incrmente l'adresse.
	movlw 0x80		; Adresse de fin + 1 (0x80)
	subwf FSR,w
	btfss STATUS,Z		; On teste si (FSR) = 0x80.
	goto clr_var		; Non : on recommence.

	movlw	1		; 1 => Pour passer tout de suite dans la boucle.
	movwf	cpt_feut1
	movwf	cpt_feut2
	movwf	cpt_chen1
	movwf	cpt_chen2
	movwf	cpt_ense1
	movwf	cpt_ense2
	movwf	cpt_croi1
	movwf	cpt_croi2

	movwf	cpt_fluo11
	movwf	cpt_fluo12
	movwf	cpt_fluo13
	movwf	cpt_fluo15

	movwf	cpt_fluo21
	movwf	cpt_fluo22
	movwf	cpt_fluo23
	movwf	cpt_fluo25

	movwf	cpt_fluo31
	movwf	cpt_fluo32
	movwf	cpt_fluo33
	movwf	cpt_fluo35

	movwf	cpt_flam01
	movwf	cpt_flam02
	movwf	cpt_flam03

	movwf	cpt_arc11
	movwf	cpt_arc12
	movwf	cpt_arc13	; Fin des boucles de pause longue dure.
	movwf	cpt_arc21
	movwf	cpt_arc22
	movwf	cpt_arc23	; Fin des boucles de pause longue dure.
	
	movlw	0x30		; Pour initialiser les gnrateurs de nombre alatoire.
	movwf	varale1s
	movwf	varale2s+1
	movlw	0x45
	movwf	varale1s+1
	movwf	varale2s

;
;***********************************************************************************************
; Lecture des cavaliers en entre de R3 et sorties RA5, RA4, RC5 et RC4.
;
	clrf	mode
	bsf	PORTC,4		; Lecture des cavaliers pour choisir le mode de fonctionnement.
	clrf	temp1		; Les autres sorties sont dj  0.
	decfsz	temp1,f
	goto	$-1             ; Petite tempo pour que l'entre multiplexe se stabilise.
	btfsc	PORTA,3
	bsf	mode,0          ; 0-0-0-1.
;
	bcf	PORTC,4
	bsf	PORTC,5
	decfsz	temp1,f
	goto	$-1             ; Petite tempo pour que l'entre multiplexe se stabilise.
	btfsc	PORTA,3
	bsf	mode,1 		; 0-0-1-0.
;	
	bcf	PORTC,5
	bsf	PORTA,4
	decfsz	temp1,f
	goto	$-1             ; Petite tempo pour que l'entre multiplexe se stabilise.
	btfsc	PORTA,3
	bsf	mode,2 		; 0-1-0-0.
;
	bcf	PORTA,4
	bsf	PORTA,5
	decfsz	temp1,f
	goto	$-1             ; Petite tempo pour que l'entre multiplexe se stabilise.
	btfsc	PORTA,3
	bsf	mode,3		; 1-0-0-0.
;
	bcf	PORTA,5		; Au dpart, teint toutes les sorties.
;
	bsf	ADCON0,GO	; Lance la conversion can pour la prochaine lecture.
	return
;
	end